@@ -1,6 +1,10 @@
 from langtrace.trace_attributes import AWSBedrockMethods
 
 APIS = {
+    "INVOKE_MODEL": {
+        "METHOD": "aws_bedrock.invoke_model",
+        "ENDPOINT": "/invoke-model",
+    },
     "CONVERSE": {
         "METHOD": AWSBedrockMethods.CONVERSE.value,
         "ENDPOINT": "/converse",
